@@ -1,5 +1,5 @@
 # These functions are
-# Copyright (C) 1998-2014 T.W. Yee, University of Auckland.
+# Copyright (C) 1998-2015 T.W. Yee, University of Auckland.
 # All rights reserved.
 
 
@@ -13,11 +13,14 @@
 
 
 
- A1A2A3 <- function(link = "logit", inbreeding = TRUE,
+ A1A2A3 <- function(link = "logit",
+                    inbreeding = FALSE,  # HWE assumption is the default
                     ip1 = NULL, ip2 = NULL, iF = NULL) {
 
 
 
+
+
   link <- as.list(substitute(link))
   earg <- link2list(link)
   link <- attr(earg, "function.name")
@@ -29,22 +32,23 @@
 
   new("vglmff",
   blurb = c("G1-G2-G3 phenotype (",
-            ifelse(inbreeding, "with", "without"),
+            ifelse(inbreeding, "without", "with"),
             " the Hardy-Weinberg equilibrium assumption)\n\n",
             "Links:    ",
             namesof("p1", link, earg = earg, tag = FALSE), ", ", 
             namesof("p2", link, earg = earg, tag = FALSE),
-            if (!inbreeding) paste(",",
+            if (inbreeding) paste(",",
             namesof("f",  link, earg = earg, tag = FALSE)) else
             ""),
   deviance = Deviance.categorical.data.vgam,
   infos = eval(substitute(function(...) {
     list(Q1 = 6,
-         M1 = ifelse( .inbreeding , 2, 3),
+         M1 = ifelse( .inbreeding , 3, 2),
          expected = TRUE,
          multipleResponses = FALSE,
-         link = if ( .inbreeding ) c("p1" = .link , "p2" = .link ) else
-                            c("p1" = .link , "p2" = .link , "f" = .link ))
+         link = if ( .inbreeding )
+                  c("p1" = .link , "p2" = .link , "f" = .link ) else
+                  c("p1" = .link , "p2" = .link  ))
   }, list( .link = link, .inbreeding = inbreeding ))),
 
   initialize = eval(substitute(expression({
@@ -68,8 +72,8 @@
     predictors.names <-
      c(namesof("p1", .link , earg = .earg , tag = FALSE),
        namesof("p2", .link , earg = .earg , tag = FALSE),
-       if ( .inbreeding ) NULL else
-       namesof("f",  .link , earg = .earg , tag = FALSE))
+       if ( .inbreeding )
+       namesof("f",  .link , earg = .earg , tag = FALSE) else NULL)
     mustart <- (y + mustart) / 2
 
 
@@ -100,8 +104,8 @@
       etastart <-
         cbind(theta2eta(p1, .link , earg = .earg ),
               theta2eta(p2, .link , earg = .earg ),
-              if ( .inbreeding ) NULL else
-              theta2eta(ff, .link , earg = .earg ))
+              if ( .inbreeding )
+              theta2eta(ff, .link , earg = .earg ) else NULL)
       mustart <- NULL  # Since etastart has been computed.
 
     }
@@ -111,8 +115,8 @@
   linkinv = eval(substitute(function(eta, extra = NULL) {
     p1 <- eta2theta(eta[, 1], link = .link , earg = .earg )
     p2 <- eta2theta(eta[, 2], link = .link , earg = .earg )
-    f  <- if ( .inbreeding ) 0 else
-          eta2theta(eta[, 3], link = .link , earg = .earg )
+    f  <- if ( .inbreeding )
+          eta2theta(eta[, 3], link = .link , earg = .earg ) else 0
     p3 <- abs(1 - p1 - p2)
       cbind("A1A1" = f*p1+(1-f)*p1^2,
             "A1A2" = 2*p1*p2*(1-f),
@@ -124,11 +128,11 @@
 
   last = eval(substitute(expression({
     if ( .inbreeding ) {
-      misc$link <-    c(p1 = .link , p2 = .link )
-      misc$earg <- list(p1 = .earg , p2 = .earg )
-    } else {
       misc$link <-    c(p1 = .link , p2 = .link , f = .link )
       misc$earg <- list(p1 = .earg , p2 = .earg , f = .earg )
+    } else {
+      misc$link <-    c(p1 = .link , p2 = .link )
+      misc$earg <- list(p1 = .earg , p2 = .earg )
     }
 
     misc$expected <- TRUE
@@ -146,60 +150,58 @@
     p1 <- eta2theta(eta[, 1], link = .link , earg = .earg )
     p2 <- eta2theta(eta[, 2], link = .link , earg = .earg )
     p3 <- 1-p1-p2
-    f  <- if ( .inbreeding ) 0 else
-          eta2theta(eta[, 3], link = .link , earg = .earg )
+    f  <- if ( .inbreeding )
+          eta2theta(eta[, 3], link = .link , earg = .earg ) else 0
     if ( .inbreeding ) {
-    dl.dp1 <- (2*y[, 1]+y[, 2]+y[, 4])/p1 -
-              (2*y[,6]+y[, 4]+y[,5])/(1-p1-p2)
-    dl.dp2 <- (2*y[, 3]+y[, 2]+y[,5])/p2 -
-              (2*y[,6]+y[, 4]+y[,5])/(1-p1-p2)
-
-    dp1.deta <- dtheta.deta(p1, link = .link , earg = .earg )
-    dp2.deta <- dtheta.deta(p2, link = .link , earg = .earg )
-
-    c(w) * cbind(dl.dp1 * dp1.deta,
-                 dl.dp2 * dp2.deta)
+      dP1 <- cbind(f + 2*p1*(1-f), 2*(1-f)*p2, 2*(1-f)*(1-p2-2*p1),
+                  0, -2*(1-f)*p2, -f - 2*p3*(1-f))
+      dP2 <- cbind(0, 2*p1*(1-f), -2*(1-f)*p1, f+2*p2*(1-f),
+                   2*(1-f)*(1-p1-2*p2), -f - 2*p3*(1-f))
+      dP3 <- cbind(p1*(1-p1), -2*p1*p2, -2*p1*p3, p2*(1-p2), -2*p2*p3, 
+                   p3*(1-p3))
+      dl1 <- rowSums(y * dP1 / mu)
+      dl2 <- rowSums(y * dP2 / mu)
+      dl3 <- rowSums(y * dP3 / mu)
+      dPP.deta <- dtheta.deta(cbind(p1, p2, f),
+                              link = .link , earg = .earg )
+      c(w) * cbind(dPP.deta[, 1] * dl1,
+                   dPP.deta[, 2] * dl2, 
+                   dPP.deta[, 3] * dl3)
     } else {
-    dP1 <- cbind(f + 2*p1*(1-f), 2*(1-f)*p2, 2*(1-f)*(1-p2-2*p1),
-                0, -2*(1-f)*p2, -f - 2*p3*(1-f))
-    dP2 <- cbind(0, 2*p1*(1-f), -2*(1-f)*p1, f+2*p2*(1-f),
-                 2*(1-f)*(1-p1-2*p2), -f - 2*p3*(1-f))
-    dP3 <- cbind(p1*(1-p1), -2*p1*p2, -2*p1*p3, p2*(1-p2), -2*p2*p3, 
-                 p3*(1-p3))
-    dl1 <- rowSums(y * dP1 / mu)
-    dl2 <- rowSums(y * dP2 / mu)
-    dl3 <- rowSums(y * dP3 / mu)
-    dPP.deta <- dtheta.deta(cbind(p1, p2, f),
-                            link = .link , earg = .earg )
-    c(w) * cbind(dPP.deta[, 1] * dl1,
-                 dPP.deta[, 2] * dl2, 
-                 dPP.deta[, 3] * dl3)
-  }
+      dl.dp1 <- (2*y[, 1]+y[, 2]+y[, 4])/p1 -
+                (2*y[,6]+y[, 4]+y[,5])/(1-p1-p2)
+      dl.dp2 <- (2*y[, 3]+y[, 2]+y[,5])/p2 -
+                (2*y[,6]+y[, 4]+y[,5])/(1-p1-p2)
+
+      dp1.deta <- dtheta.deta(p1, link = .link , earg = .earg )
+      dp2.deta <- dtheta.deta(p2, link = .link , earg = .earg )
+
+      c(w) * cbind(dl.dp1 * dp1.deta,
+                   dl.dp2 * dp2.deta)
+    }
   }), list( .link = link, .earg = earg, .inbreeding = inbreeding ))),
   weight = eval(substitute(expression({
     if ( .inbreeding ) {
-    qq <- 1-p1-p2
-    wz <- matrix(as.numeric(NA), n, dimm(M))  # dimm(M)==3 because M==2
-    ned2l.dp12  <-  2 * (1/p1 + 1/qq)
-    ned2l.dp22  <-  2 * (1/p2 + 1/qq)
-    ned2l.dp1dp2 <-  2 / qq
-    wz[, iam(1, 1, M)] <- ned2l.dp12 * dp1.deta^2
-    wz[, iam(2, 2, M)] <- ned2l.dp22 * dp2.deta^2
-    wz[, iam(1, 2, M)] <- ned2l.dp1dp2 * dp1.deta * dp2.deta
-    c(w) * wz
+      dPP <- array(c(dP1, dP2, dP3), c(n, 6, 3))
+      wz <- matrix(as.numeric(NA), n, dimm(M))  # dimm(M)==6 because M==3
+      for (i1 in 1:M)
+        for (i2 in i1:M) {
+          index <- iam(i1, i2, M)
+          wz[, index] <- rowSums(dPP[, , i1, drop = TRUE] *
+                                 dPP[, , i2, drop = TRUE] / mu) *
+                                 dPP.deta[, i1] * dPP.deta[, i2]
+      }
     } else {
-    dPP <- array(c(dP1, dP2, dP3), c(n, 6, 3))
-
-    wz <- matrix(as.numeric(NA), n, dimm(M))  # dimm(M)==6 because M==3
-    for (i1 in 1:M)
-      for (i2 in i1:M) {
-        index <- iam(i1,i2, M)
-        wz[,index] <- rowSums(dPP[, , i1, drop = TRUE] *
-                              dPP[, , i2, drop = TRUE] / mu) *
-                              dPP.deta[, i1] * dPP.deta[, i2]
+      qq <- 1-p1-p2
+      wz <- matrix(as.numeric(NA), n, dimm(M))  # dimm(M)==3 because M==2
+      ned2l.dp12  <-  2 * (1/p1 + 1/qq)
+      ned2l.dp22  <-  2 * (1/p2 + 1/qq)
+      ned2l.dp1dp2 <-  2 / qq
+      wz[, iam(1, 1, M)] <- ned2l.dp12 * dp1.deta^2
+      wz[, iam(2, 2, M)] <- ned2l.dp22 * dp2.deta^2
+      wz[, iam(1, 2, M)] <- ned2l.dp1dp2 * dp1.deta * dp2.deta
     }
     c(w) * wz
-  }
   }), list( .link = link, .earg = earg, .inbreeding = inbreeding ))))
 }
 
@@ -650,18 +652,41 @@ if (FALSE)
 
 
 
- ABO <- function(link = "logit", ipA = NULL, ipO = NULL) {
-  link <- as.list(substitute(link))
-  earg <- link2list(link)
-  link <- attr(earg, "function.name")
+ ABO <- function(link.pA = "logit", link.pB = "logit",
+                 ipA = NULL, ipB = NULL, ipO = NULL,
+                 zero = NULL) {
+  link.pA <- as.list(substitute(link.pA))
+  earg.pA <- link2list(link.pA)
+  link.pA <- attr(earg.pA, "function.name")
+
+  link.pB <- as.list(substitute(link.pB))
+  earg.pB <- link2list(link.pB)
+  link.pB <- attr(earg.pB, "function.name")
 
 
   new("vglmff",
   blurb = c("ABO Blood Group System (A-B-AB-O phenotype)\n\n",
             "Links:    ",
-            namesof("pA", link, earg = earg), ", ", 
-            namesof("pB", link, earg = earg, tag = FALSE)),
+            namesof("pA", link.pA, earg = earg.pA, tag = FALSE), ", ", 
+            namesof("pB", link.pB, earg = earg.pB, tag = FALSE)),
   deviance = Deviance.categorical.data.vgam,
+  infos = eval(substitute(function(...) {
+    list(M1 = 2,
+         Q1 = 4,
+         multipleResponses = FALSE,
+         expected = TRUE,
+         zero = .zero ,
+         link = c("pA" = .link.pA , "pB" = .link.pB ),
+         earg = c("pA" = .earg.pB , "pB" = .earg.pB )
+        )
+  }, list( .link.pA = link.pA, .link.pB = link.pB,
+           .earg.pA = earg.pA, .earg.pB = earg.pB,
+           .zero = zero ))),
+
+  constraints = eval(substitute(expression({
+    constraints <- cm.zero.VGAM(constraints, x, .zero , M)
+  }), list( .zero = zero ))),
+
 
   initialize = eval(substitute(expression({
     mustart.orig <- mustart
@@ -682,40 +707,44 @@ if (FALSE)
 
 
     predictors.names <-
-      c(namesof("pA", .link , earg = .earg , tag = FALSE),
-        namesof("pB", .link , earg = .earg , tag = FALSE))
+      c(namesof("pA", .link.pA , earg = .earg.pA , tag = FALSE),
+        namesof("pB", .link.pB , earg = .earg.pB , tag = FALSE))
     mustart <- (y + mustart) / 2
 
     if (!length(etastart)) {
       pO <- if (is.Numeric( .ipO )) rep( .ipO , len = n) else
         rep(c(sqrt( weighted.mean(mustart[, 4], w)) ), len = n)
       pA <- if (is.Numeric( .ipA )) rep( .ipA , len = n) else
-        rep(c(1 - sqrt(weighted.mean(mustart[, 2] + mustart[, 4], w))), len = n)
-      pB <- abs(1 - pA - pO)
-      etastart <- cbind(theta2eta(pA, .link , earg = .earg ),
-                        theta2eta(pB, .link , earg = .earg ))
+        rep(c(1 - sqrt(weighted.mean(mustart[, 2] + mustart[, 4], w))),
+            len = n)
+      pB <- if (is.Numeric( .ipB )) rep( .ipB , len = n) else
+            abs(1 - pA - pO)
+      etastart <- cbind(theta2eta(pA, .link.pA , earg = .earg.pA ),
+                        theta2eta(pB, .link.pB , earg = .earg.pB ))
       mustart <- NULL  # Since etastart has been computed.
     }
-  }), list( .link = link, .ipO = ipO, .ipA = ipA, .earg = earg))),
+  }), list( .link.pA = link.pA, .link.pB = link.pB,
+            .ipO = ipO, .ipA = ipA, .ipB = ipB,
+            .earg.pA = earg.pA, .earg.pB = earg.pB ))),
 
 
   linkinv = eval(substitute(function(eta, extra = NULL) {
-      pA <- eta2theta(eta[, 1], link = .link , earg = .earg )
-      pB <- eta2theta(eta[, 2], link = .link , earg = .earg )
+      pA <- eta2theta(eta[, 1], link = .link.pA , earg = .earg.pA )
+      pB <- eta2theta(eta[, 2], link = .link.pB , earg = .earg.pB )
       pO <- abs(1 - pA - pB)
       cbind(A  = pA*(pA+2*pO),
             B  = pB*(pB+2*pO),
             AB = 2*pA*pB,
             O  = pO*pO) 
-  }, list( .link = link, .earg = earg))),
+  }, list( .link.pA = link.pA, .link.pB = link.pB,
+           .earg.pA = earg.pA, .earg.pB = earg.pB ))),
 
   last = eval(substitute(expression({
-    misc$link <-    c(pA = .link , pB = .link )
-
-    misc$earg <- list(pA = .earg , pB = .earg )
-
+    misc$link <-    c(pA = .link.pA , pB = .link.pB )
+    misc$earg <- list(pA = .earg.pA , pB = .earg.pB )
     misc$expected <- TRUE
-  }), list( .link = link, .earg = earg))),
+  }), list( .link.pA = link.pA, .link.pB = link.pB,
+            .earg.pA = earg.pA, .earg.pB = earg.pB ))),
 
 
   loglikelihood =
@@ -729,8 +758,8 @@ if (FALSE)
   vfamily = c("ABO", "vgenetic"),
 
   deriv = eval(substitute(expression({
-    ppp <- eta2theta(eta[, 1], link = .link , earg = .earg )
-    qqq <- eta2theta(eta[, 2], link = .link , earg = .earg )
+    ppp <- eta2theta(eta[, 1], link = .link.pA , earg = .earg.pA )
+    qqq <- eta2theta(eta[, 2], link = .link.pB , earg = .earg.pB )
     rrr <- abs(1 - ppp - qqq)
 
 
@@ -743,12 +772,13 @@ if (FALSE)
 
     dl.dp <- (naa+nab)/ppp -   naa/pbar - 2*nbb/qbar - 2*noo/rrr
     dl.dq <- (nbb+nab)/qqq - 2*naa/pbar -   nbb/qbar - 2*noo/rrr
-    dp.deta <- dtheta.deta(ppp, link = .link , earg = .earg )
-    dq.deta <- dtheta.deta(qqq, link = .link , earg = .earg )
+    dp.deta <- dtheta.deta(ppp, link = .link.pA , earg = .earg.pA )
+    dq.deta <- dtheta.deta(qqq, link = .link.pB , earg = .earg.pB )
 
     c(w) * cbind(dl.dp * dp.deta,
                  dl.dq * dq.deta)
-  }), list( .link = link, .earg = earg))),
+  }), list( .link.pA = link.pA, .link.pB = link.pB,
+            .earg.pA = earg.pA, .earg.pB = earg.pB ))),
 
   weight = eval(substitute(expression({
     wz <- matrix(as.numeric(NA), n, dimm(M))  # dimm(M)==3 because M==2
@@ -757,11 +787,12 @@ if (FALSE)
     ned2l.dq2  <- (1 + 2/qqq + 4*ppp/pbar + qqq/qbar)
     ned2l.dpdq <- 2 * (1 + qqq/qbar + ppp/pbar)
 
-    wz[, iam(1, 1, M)] <- ned2l.dp2 * dp.deta^2
-    wz[, iam(2, 2, M)] <- ned2l.dq2 * dq.deta^2
+    wz[, iam(1, 1, M)] <- ned2l.dp2  * dp.deta^2
+    wz[, iam(2, 2, M)] <- ned2l.dq2  * dq.deta^2
     wz[, iam(1, 2, M)] <- ned2l.dpdq * dp.deta * dq.deta
     c(w) * wz
-  }), list( .link = link, .earg = earg))))
+  }), list( .link.pA = link.pA, .link.pB = link.pB,
+            .earg.pA = earg.pA, .earg.pB = earg.pB ))))
 }
 
 
@@ -865,10 +896,12 @@ if (FALSE)
 
 
 
+
+
  AA.Aa.aa <-
   function(linkp = "logit",
            linkf = "logit",
-           inbreeding = TRUE,
+           inbreeding = FALSE,  # HWE assumption is the default
            ipA = NULL,
            ifp = NULL,
            zero = NULL) {
@@ -888,22 +921,22 @@ if (FALSE)
 
   new("vglmff",
   blurb = c("AA-Aa-aa phenotype (",
-            ifelse(inbreeding, "with", "without"),
+            ifelse(inbreeding, "without", "with"),
             " the Hardy-Weinberg equilibrium assumption)\n\n",
             "Links:    ",
             namesof("pA", linkp, earg = eargp, tag = FALSE),
-            if (!inbreeding) paste(",",
+            if (inbreeding) paste(",",
             namesof("f",  linkf, earg = eargf, tag = FALSE)) else
             ""),
   deviance = Deviance.categorical.data.vgam,
   infos = eval(substitute(function(...) {
-    list(M1 = ifelse( .inbreeding , 1, 2),
+    list(M1 = ifelse( .inbreeding , 2, 1),
          Q1 = 3,
          multipleResponses = FALSE,
          expected = TRUE,
          zero = .zero ,
-         link = if ( .inbreeding ) c("pA" = .linkp ) else
-                            c("pA" = .linkp , "f" = .linkf ))
+         link = if ( .inbreeding ) c("pA" = .linkp , "f" = .linkf ) else
+                            c("pA" = .linkp ))
   }, list( .linkp = linkp,
            .linkf = linkf, .inbreeding = inbreeding,
            .zero = zero ))),
@@ -928,8 +961,8 @@ if (FALSE)
 
     predictors.names <-
       c(namesof("pA", .linkp , earg = .eargp , tag = FALSE),
-        if ( .inbreeding ) NULL else
-        namesof("f",  .linkf , earg = .eargf , tag = FALSE))
+        if ( .inbreeding )
+        namesof("f",  .linkf , earg = .eargf , tag = FALSE) else NULL)
     mustart <- (y + mustart) / 2
         
 
@@ -939,8 +972,8 @@ if (FALSE)
       fp <- if (is.numeric( .ifp )) rep( .ifp , len = n) else
               runif(n)  # 1- mustart[, 2]/(2*pA*(1-pA))
       etastart <- cbind(theta2eta(pA, .linkp , earg = .eargp ),
-                        if ( .inbreeding ) NULL else
-                        theta2eta(fp, .linkf , earg = .eargf ) )
+                        if ( .inbreeding )
+                        theta2eta(fp, .linkf , earg = .eargf ) else NULL)
       mustart <- NULL  # Since etastart has been computed.
     }
   }), list( .linkp = linkp, .linkf = linkf,
@@ -949,8 +982,8 @@ if (FALSE)
   linkinv = eval(substitute(function(eta, extra = NULL) {
     eta <- as.matrix(eta)
     pA <- eta2theta(eta[, 1], link = .linkp , earg = .eargp )
-    fp <- if ( .inbreeding ) 0 else
-          eta2theta(eta[, 2], link = .linkf , earg = .eargf )
+    fp <- if ( .inbreeding )
+          eta2theta(eta[, 2], link = .linkf , earg = .eargf ) else 0
 
     cbind(AA = pA^2 + pA * (1-pA) * fp,
           Aa = 2 * pA * (1-pA) * (1 - fp),
@@ -961,11 +994,11 @@ if (FALSE)
 
   last = eval(substitute(expression({
     if ( .inbreeding ) {
-      misc$link <-    c("pA" = .linkp )
-      misc$earg <- list("pA" = .eargp )
-    } else {
       misc$link <-    c("pA" = .linkp, "f" = .linkf )
       misc$earg <- list("pA" = .eargp, "f" = .eargf )
+    } else {
+      misc$link <-    c("pA" = .linkp )
+      misc$earg <- list("pA" = .eargp )
     }
     misc$expected <- TRUE
   }), list( .linkp = linkp, .linkf = linkf,
@@ -984,17 +1017,10 @@ if (FALSE)
   deriv = eval(substitute(expression({
     eta <- as.matrix(eta)
     pA <- eta2theta(eta[, 1], link = .linkp , earg = .eargp )
-    fp <- if ( .inbreeding ) 0 else
-          eta2theta(eta[, 2], link = .linkf , earg = .eargf )
+    fp <- if ( .inbreeding )
+          eta2theta(eta[, 2], link = .linkf , earg = .eargf ) else 0
 
     if ( .inbreeding ) {
-      nAA <- w * y[, 1]
-      nAa <- w * y[, 2]
-      naa <- w * y[, 3]
-      dl.dpA <- (2*nAA+nAa)/pA - (nAa+2*naa)/(1-pA)
-      dpA.deta <- dtheta.deta(pA, link = .linkp , earg = .eargp )
-      dl.dpA * dpA.deta
-    } else {
       dP1 <- cbind(fp + 2*pA*(1-fp),
                     2*(1-fp)*(1-2*pA),
                    -2*(1-pA) + fp*(1-2*pA))
@@ -1009,16 +1035,19 @@ if (FALSE)
 
       c(w) * cbind(dPP.deta * dl1,
                    dfp.deta * dl2)      
+    } else {
+      nAA <- w * y[, 1]
+      nAa <- w * y[, 2]
+      naa <- w * y[, 3]
+      dl.dpA <- (2*nAA+nAa)/pA - (nAa+2*naa)/(1-pA)
+      dpA.deta <- dtheta.deta(pA, link = .linkp , earg = .eargp )
+      dl.dpA * dpA.deta
     }  
   }), list( .linkp = linkp, .linkf = linkf,
             .eargp = eargp, .eargf = eargf,
             .inbreeding = inbreeding ))),
   weight = eval(substitute(expression({
     if ( .inbreeding ) {
-      ned2l.dp2 <- (2*nAA+nAa)/pA^2 + (nAa+2*naa)/(1-pA)^2
-      wz <- cbind((dpA.deta^2) * ned2l.dp2)
-      wz
-    } else {
       dPP <- array(c(dP1, dP2), c(n, 3, 2))
       dPP.deta <- cbind(dtheta.deta(pA, link = .linkp , earg = .eargp ),
                         dtheta.deta(fp, link = .linkf , earg = .eargf ))
@@ -1031,6 +1060,10 @@ if (FALSE)
                                  dPP.deta[, i1] * dPP.deta[, i2]
         }
       c(w) * wz
+    } else {
+      ned2l.dp2 <- (2*nAA + nAa) / pA^2 + (nAa + 2*naa) / (1-pA)^2
+      wz <- cbind((dpA.deta^2) * ned2l.dp2)
+      wz
     }
   }), list( .linkp = linkp, .linkf = linkf,
             .eargp = eargp, .eargf = eargf,
